/***************************************************************************
 *   Copyright (C) 2008 by Lisandro Damián Nicanor Pérez Meyer             *
 *   perezmeyer@gmail.com                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "practico6.h"

#include "glwidget.h"

Practico6::Practico6(QWidget *)
{
	// We set the main window
	mainWindow.setupUi(this);

	// Connect the check box with the axis draw state
	connect(mainWindow.drawAxisCheckBox, SIGNAL(stateChanged(int)),
	        this, SLOT(setDrawAxis(int)));
	connect(this, SIGNAL(changeDrawAxis(bool)),
	        mainWindow.glWidget, SLOT(setDrawAxis(bool)));

	// Connect the figures checkboxes with the selection functions
	connect(mainWindow.patchRadioButton, SIGNAL(toggled(bool)),
	        this, SLOT(patchSelected(bool)));
	connect(mainWindow.tubeRadioButton, SIGNAL(toggled(bool)),
	        this, SLOT(tubeSelected(bool)));
	connect(mainWindow.semiTubeRadioButton, SIGNAL(toggled(bool)),
	        this, SLOT(semiTubeSelected(bool)));
	connect(mainWindow.torusRadioButton,SIGNAL(toggled(bool)),
	        this, SLOT(torusSelected(bool)));

	// Connect the selection function to the glwidget
	connect(this, SIGNAL(changeFigure(Constants::Figures)),
	        mainWindow.glWidget, SLOT(setFigure(Constants::Figures)));

	// Connect the methods with the selections functions
	connect(mainWindow.bezierRadioButton, SIGNAL(toggled(bool)),
	        this, SLOT(bezierSelected(bool)));
	connect(mainWindow.bSplinesRadioButton,SIGNAL(toggled(bool)),
	        this, SLOT(bSplinesSelected(bool)));

	// Connect the method function to the glwidget
	connect(this, SIGNAL(changeMethod(Constants::Methods)),
	        mainWindow.glWidget, SLOT(setMethod(Constants::Methods)));

	// Set the state of the axis check box
	mainWindow.drawAxisCheckBox->setCheckState(Qt::Checked);
	mainWindow.glWidget->setDrawAxis(true);

	// Set the current figure to patch
	mainWindow.patchRadioButton->setChecked(true);

	// Set the current method to Bezier
	mainWindow.bezierRadioButton->setChecked(true);

	mainWindow.statusbar->showMessage(tr("Use the left and right mouse buttons "
	                                     "to change the XY and XZ coordinates "
	                                     "of the viewer"));
}

void Practico6::setDrawAxis(int state)
{
	if(state == Qt::Checked)
		emit changeDrawAxis(true);
	else
		emit changeDrawAxis(false);
}

void Practico6::patchSelected(bool selected)
{
	if(selected)
		emit changeFigure(Constants::Patch);
}

void Practico6::tubeSelected(bool selected)
{
	if(selected)
		emit changeFigure(Constants::Tube);
}

void Practico6::semiTubeSelected(bool selected)
{
	if(selected)
		emit changeFigure(Constants::SemiTube);
}

void Practico6::torusSelected(bool selected)
{
	if(selected)
		emit changeFigure(Constants::Torus);
}

void Practico6::bezierSelected(bool selected)
{
	if(selected)
		emit changeMethod(Constants::Bezier);
}

void Practico6::bSplinesSelected(bool selected)
{
	if(selected)
		emit changeMethod(Constants::BSplines);
}

